@@ -22,11 +22,12 @@ our @EXPORT_OK = qw(
 );
 
 # ABSTRACT: Check that a library is available for FFI
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 
 our $system_path = [];
 our $os ||= $^O;
+my $try_ld_on_text = 0;
 
 if($os eq 'MSWin32' || $os eq 'msys')
 {
@@ -47,6 +48,7 @@ else
 }
 
 our $pattern = [ qr{^lib(.*?)\.so(?:\.([0-9]+(?:\.[0-9]+)*))?$} ];
+our $version_split = qr/\./;
 
 if($os eq 'cygwin')
 {
@@ -61,22 +63,32 @@ elsif($os eq 'msys')
 }
 elsif($os eq 'MSWin32')
 {
-  $pattern = [ qr{^(?:lib)?(.*?)(?:-([0-9])+)?\.dll$}i ];
+  #  handle cases like libgeos-3-7-0___.dll and libgtk-2.0-0.dll
+  $pattern = [ qr{^(?:lib)?(\w+?)(?:-([0-9-\.]+))?_*\.dll$}i ];
+  $version_split = qr/\-/;
 }
 elsif($os eq 'darwin')
 {
   push @$pattern, qr{^lib(.*?)(?:\.([0-9]+(?:\.[0-9]+)*))?\.(?:dylib|bundle)$};
 }
+elsif($os eq 'linux')
+{
+  if(-e '/etc/redhat-release' && -x '/usr/bin/ld')
+  {
+    $try_ld_on_text = 1;
+  }
+}
 
 sub _matches
 {
   my($filename, $path) = @_;
+
   foreach my $regex (@$pattern)
   {
     return [
-      $1,                                      # 0    capture group 1 library name
-      File::Spec->catfile($path, $filename),   # 1    full path to library
-      defined $2 ? (split /\./, $2) : (),      # 2... capture group 2 library version
+      $1,                                            # 0    capture group 1 library name
+      File::Spec->catfile($path, $filename),         # 1    full path to library
+      defined $2 ? (split $version_split, $2) : (),  # 2... capture group 2 library version
     ] if $filename =~ $regex;
   }
   return ();
@@ -102,6 +114,11 @@ sub _cmp
 
 my $diagnostic;
 
+sub _is_binary
+{
+  -B $_[0]
+}
+
 sub find_lib
 {
   my(%args) = @_;
@@ -161,6 +178,20 @@ sub find_lib
       readdir $dh;
     closedir $dh;
 
+    if($try_ld_on_text && $args{try_linker_script})
+    {
+      # This is tested in t/ci.t only
+      @maybe = map {
+        -B $_->[1] ? $_ : do {
+          my($name, $so) = @$_;
+          my $output = `/usr/bin/ld -t $so -o /dev/null -shared`;
+          $output =~ /\((.*?lib.*\.so.*?)\)/
+            ? [$name, $1]
+            : die "unable to parse ld output";
+        }
+      } @maybe;
+    }
+
     midloop:
     foreach my $lib (@maybe)
     {
@@ -344,7 +375,7 @@ FFI::CheckLib - Check that a library is available for FFI
 
 =head1 VERSION
 
-version 0.22
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -451,6 +482,20 @@ Example:
 Recursively search for libraries in any non-system paths (those provided
 via C<libpath> above).
 
+=item try_linker_script
+
+[version 0.24]
+
+Some vendors provide C<.so> files that are linker scripts that point to
+the real binary shared library.  These linker scripts can be used by gcc
+or clang, but are not directly usable by L<FFI::Platypus> and friends.
+On select platforms, this options will use the linker command (C<ld>)
+to attempt to resolve the real C<.so> for non-binary files.  Since there
+is extra overhead this is off by default.
+
+An example is libyaml on RedHat based Linux distributions.  On Debian
+these are handled with symlinks and no trickery is required.
+
 =back
 
 =head2 assert_lib
@@ -537,7 +582,7 @@ Not exported by default.
  my $path = FFI::CheckLib::system_path;
 
 Returns the system path as a list reference.  On some systems, this is C<PATH>
-on others it might be L<LD_LIBRARY_PATH> on still others it could be something
+on others it might be C<LD_LIBRARY_PATH> on still others it could be something
 completely different.  So although you I<may> add items to this list, you should
 probably do some careful consideration before you do so.
 
@@ -569,6 +614,8 @@ Dan Book (grinnz, DBOOK)
 
 Ilya Pavlov (Ilya, ILUX)
 
+Shawn Laffan (SLAFFAN)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014-2018 by Graham Ollis.
